==> tomee-project-8.0.10-source-release.zip: tomee-project-8.0.10/container/openejb-core/src/test/java/org/apache/openejb/core/stateless/ThisInConstructorTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.core.stateless;

import org.apache.openejb.jee.Empty;
import org.apache.openejb.jee.StatelessBean;
import org.apache.openejb.junit.ApplicationComposer;
import org.apache.openejb.testing.Module;
import org.junit.Test;
import org.junit.runner.RunWith;

import javax.ejb.EJB;
import javax.ejb.Stateless;

import static org.junit.Assert.assertNotNull;

@RunWith(ApplicationComposer.class)
public class ThisInConstructorTest {
    @EJB
    private AStatelessWithAConstructor stateless;

    @Test
    public void validThis() {
        assertNotNull(stateless);
        assertNotNull(stateless.getThat());
    }

    @Module
    public StatelessBean bean() {
        final StatelessBean bean = new StatelessBean(AStatelessWithAConstructor.class);
        bean.setLocalBean(new Empty());
        return bean;
    }

    @Stateless
    public static class AStatelessWithAConstructor {
        private final AStatelessWithAConstructor that;

        public AStatelessWithAConstructor() {
            that = this;
            System.out.println(this);
        }

        public AStatelessWithAConstructor getThat() {
            return that;
        }
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/container/openejb-core/src/test/java/org/apache/openejb/core/stateless/ThisInConstructorTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.core.stateless;

import org.apache.openejb.jee.Empty;
import org.apache.openejb.jee.StatelessBean;
import org.apache.openejb.junit.ApplicationComposer;
import org.apache.openejb.testing.Module;
import org.junit.Test;
import org.junit.runner.RunWith;

import jakarta.ejb.EJB;
import jakarta.ejb.Stateless;

import static org.junit.Assert.assertNotNull;

@RunWith(ApplicationComposer.class)
public class ThisInConstructorTest {
    @EJB
    private AStatelessWithAConstructor stateless;

    @Test
    public void validThis() {
        assertNotNull(stateless);
        assertNotNull(stateless.getThat());
    }

    @Module
    public StatelessBean bean() {
        final StatelessBean bean = new StatelessBean(AStatelessWithAConstructor.class);
        bean.setLocalBean(new Empty());
        return bean;
    }

    @Stateless
    public static class AStatelessWithAConstructor {
        private final AStatelessWithAConstructor that;

        public AStatelessWithAConstructor() {
            that = this;
            System.out.println(this);
        }

        public AStatelessWithAConstructor getThat() {
            return that;
        }
    }
}
